==> org.robokind.impl.motion-0.9.4-sources.jar: org/robokind/impl/motion/osgi/Activator.java <==
/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.robokind.impl.motion.osgi;

import java.util.logging.Level;
import java.util.logging.Logger;
import javax.jms.BytesMessage;
import org.jflux.impl.services.rk.osgi.lifecycle.OSGiComponentFactory;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.robokind.impl.motion.config.RobotConfigXMLFileLoader;
import org.robokind.impl.motion.config.RobotConfigXMLReader;
import org.robokind.impl.motion.jointgroup.RobotJointGroupXMLFileLoader;
import org.robokind.impl.motion.jointgroup.RobotJointGroupConfigXMLReader;
import org.robokind.api.motion.jointgroup.RobotJointGroupFactory;
import org.robokind.api.common.services.ServiceUtils;
import org.robokind.api.motion.messaging.RobotResponseFactory;
import org.robokind.api.motion.protocol.MotionFrameEvent;
import org.robokind.api.motion.protocol.RobotDefinitionResponse;
import org.robokind.api.motion.protocol.RobotRequest;
import org.robokind.api.motion.protocol.RobotResponse;
import org.robokind.api.motion.protocol.RobotResponse.RobotPositionResponse;
import org.robokind.api.motion.protocol.RobotResponse.RobotStatusResponse;
import org.robokind.impl.messaging.JMSAvroServiceFacade;
import org.robokind.impl.messaging.config.RKMessagingConfigUtils;
import org.robokind.impl.motion.config.RobotConfigXMLStreamLoader;
import org.robokind.impl.motion.jointgroup.RobotJointGroupXMLStreamLoader;
import org.robokind.impl.motion.messaging.MotionFrameEventRecord;
import org.robokind.impl.motion.messaging.PortableMotionFrameEvent;
import org.robokind.impl.motion.messaging.PortableRobotDefinitionResponse;
import org.robokind.impl.motion.messaging.PortableRobotPositionResponse;
import org.robokind.impl.motion.messaging.PortableRobotRequest;
import org.robokind.impl.motion.messaging.PortableRobotResponse;
import org.robokind.impl.motion.messaging.PortableRobotStatusResponse;
import org.robokind.impl.motion.messaging.RobotDefinitionResponseRecord;
import org.robokind.impl.motion.messaging.RobotPositionResponseRecord;
import org.robokind.impl.motion.messaging.RobotRequestRecord;
import org.robokind.impl.motion.messaging.RobotStatusResponseRecord;
import org.robokind.impl.motion.sync.SynchronizedRobotConfigLoader;
import org.robokind.impl.motion.sync.SynchronizedRobotConfigWriter;

/**
 * 
 * @author Matthew Stevenson <www.robokind.org>
 */
public class Activator implements BundleActivator {
    private final static Logger theLogger = Logger.getLogger(Activator.class.getName());
    
    @Override
    public void start(BundleContext context) throws Exception {
        theLogger.log(Level.INFO, "MotionAPI Activation Begin.");
        ServiceUtils.registerConfigLoader(
                context, new RobotConfigXMLReader(context));
        
        ServiceUtils.registerConfigLoader(
                context, new RobotConfigXMLFileLoader(context));
        
        ServiceUtils.registerConfigLoader(
                context, new RobotConfigXMLStreamLoader(context));
        
        ServiceUtils.registerConfigLoader(
                context, new RobotJointGroupConfigXMLReader());
        
        ServiceUtils.registerConfigLoader(
                context, new RobotJointGroupXMLFileLoader());
        
        ServiceUtils.registerConfigLoader(
                context, new RobotJointGroupXMLStreamLoader());
        
        ServiceUtils.registerFactory(
                context, new RobotJointGroupFactory());
        ServiceUtils.registerConfigLoader(
                context, new SynchronizedRobotConfigLoader());
        
        ServiceUtils.registerConfigWriter(
                context, new SynchronizedRobotConfigWriter(), null);
        
        context.registerService(RobotResponseFactory.class.getName(), 
                new PortableRobotResponse.Factory(), null);
        
        RKMessagingConfigUtils.registerAvroSerializationConfig(
                MotionFrameEvent.class, 
                MotionFrameEventRecord.class, 
                MotionFrameEventRecord.SCHEMA$, 
                new PortableMotionFrameEvent.MessageRecordAdapter(), 
                new PortableMotionFrameEvent.RecordMessageAdapter(), 
                JMSAvroServiceFacade.AVRO_MIME_TYPE, null, 
                new OSGiComponentFactory(context));
        
        RKMessagingConfigUtils.registerAvroSerializationConfig(
                RobotRequest.class, 
                RobotRequestRecord.class, 
                RobotRequestRecord.SCHEMA$, 
                new PortableRobotRequest.MessageRecordAdapter(), 
                new PortableRobotRequest.RecordMessageAdapter(), 
                JMSAvroServiceFacade.AVRO_MIME_TYPE, null, 
                new OSGiComponentFactory(context));
        
        RKMessagingConfigUtils.registerAvroSerializationConfig(
                RobotDefinitionResponse.class, 
                RobotDefinitionResponseRecord.class, 
                RobotDefinitionResponseRecord.SCHEMA$, 
                new PortableRobotDefinitionResponse.MessageRecordAdapter(), 
                new PortableRobotDefinitionResponse.RecordMessageAdapter(), 
                PortableRobotResponse.MIME_ROBOT_DEFINITION_RESPONSE, null, 
                new OSGiComponentFactory(context));
        
        RKMessagingConfigUtils.registerAvroSerializationConfig(
                RobotPositionResponse.class, 
                RobotPositionResponseRecord.class, 
                RobotPositionResponseRecord.SCHEMA$, 
                new PortableRobotPositionResponse.MessageRecordAdapter(), 
                new PortableRobotPositionResponse.RecordMessageAdapter(), 
                PortableRobotResponse.MIME_ROBOT_POSITION_RESPONSE, null, 
                new OSGiComponentFactory(context));
        
        RKMessagingConfigUtils.registerAvroSerializationConfig(
                RobotStatusResponse.class, 
                RobotStatusResponseRecord.class, 
                RobotStatusResponseRecord.SCHEMA$, 
                new PortableRobotStatusResponse.MessageRecordAdapter(), 
                new PortableRobotStatusResponse.RecordMessageAdapter(), 
                PortableRobotResponse.MIME_ROBOT_STATUS_RESPONSE, null, 
                new OSGiComponentFactory(context));
        
        RKMessagingConfigUtils.registerSerializationConfig(
                RobotResponse.class, BytesMessage.class, 
                new PortableRobotResponse.MessageRecordAdapter(), 
                new PortableRobotResponse.RecordMessageAdapter(), 
                null, null, new OSGiComponentFactory(context));
        
        theLogger.log(Level.INFO, "MotionAPI Activation Complete.");
    }

    @Override
    public void stop(BundleContext context) throws Exception {}

}

==> org.robokind.impl.motion-0.9.5-sources.jar: org/robokind/impl/motion/osgi/Activator.java <==
/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.robokind.impl.motion.osgi;

import java.util.logging.Level;
import java.util.logging.Logger;
import javax.jms.BytesMessage;
import org.jflux.impl.messaging.rk.config.RKMessagingConfigUtils;
import org.jflux.impl.services.rk.osgi.lifecycle.OSGiComponentFactory;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.robokind.impl.motion.config.RobotConfigXMLFileLoader;
import org.robokind.impl.motion.config.RobotConfigXMLReader;
import org.robokind.impl.motion.jointgroup.RobotJointGroupXMLFileLoader;
import org.robokind.impl.motion.jointgroup.RobotJointGroupConfigXMLReader;
import org.robokind.api.motion.jointgroup.RobotJointGroupFactory;
import org.robokind.api.common.services.ServiceUtils;
import org.robokind.api.motion.messaging.RobotResponseFactory;
import org.robokind.api.motion.protocol.MotionFrameEvent;
import org.robokind.api.motion.protocol.RobotDefinitionResponse;
import org.robokind.api.motion.protocol.RobotRequest;
import org.robokind.api.motion.protocol.RobotResponse;
import org.robokind.api.motion.protocol.RobotResponse.RobotPositionResponse;
import org.robokind.api.motion.protocol.RobotResponse.RobotStatusResponse;
import org.robokind.impl.messaging.JMSAvroServiceFacade;
import org.robokind.impl.motion.config.RobotConfigXMLStreamLoader;
import org.robokind.impl.motion.jointgroup.RobotJointGroupXMLStreamLoader;
import org.robokind.impl.motion.messaging.MotionFrameEventRecord;
import org.robokind.impl.motion.messaging.PortableMotionFrameEvent;
import org.robokind.impl.motion.messaging.PortableRobotDefinitionResponse;
import org.robokind.impl.motion.messaging.PortableRobotPositionResponse;
import org.robokind.impl.motion.messaging.PortableRobotRequest;
import org.robokind.impl.motion.messaging.PortableRobotResponse;
import org.robokind.impl.motion.messaging.PortableRobotStatusResponse;
import org.robokind.impl.motion.messaging.RobotDefinitionResponseRecord;
import org.robokind.impl.motion.messaging.RobotPositionResponseRecord;
import org.robokind.impl.motion.messaging.RobotRequestRecord;
import org.robokind.impl.motion.messaging.RobotStatusResponseRecord;
import org.robokind.impl.motion.sync.SynchronizedRobotConfigLoader;
import org.robokind.impl.motion.sync.SynchronizedRobotConfigWriter;

/**
 * 
 * @author Matthew Stevenson <www.robokind.org>
 */
public class Activator implements BundleActivator {
    private final static Logger theLogger = Logger.getLogger(Activator.class.getName());
    
    @Override
    public void start(BundleContext context) throws Exception {
        theLogger.log(Level.INFO, "MotionAPI Activation Begin.");
        ServiceUtils.registerConfigLoader(
                context, new RobotConfigXMLReader(context));
        
        ServiceUtils.registerConfigLoader(
                context, new RobotConfigXMLFileLoader(context));
        
        ServiceUtils.registerConfigLoader(
                context, new RobotConfigXMLStreamLoader(context));
        
        ServiceUtils.registerConfigLoader(
                context, new RobotJointGroupConfigXMLReader());
        
        ServiceUtils.registerConfigLoader(
                context, new RobotJointGroupXMLFileLoader());
        
        ServiceUtils.registerConfigLoader(
                context, new RobotJointGroupXMLStreamLoader());
        
        ServiceUtils.registerFactory(
                context, new RobotJointGroupFactory());
        ServiceUtils.registerConfigLoader(
                context, new SynchronizedRobotConfigLoader());
        
        ServiceUtils.registerConfigWriter(
                context, new SynchronizedRobotConfigWriter(), null);
        
        context.registerService(RobotResponseFactory.class.getName(), 
                new PortableRobotResponse.Factory(), null);
        
        RKMessagingConfigUtils.registerAvroSerializationConfig(
                MotionFrameEvent.class, 
                MotionFrameEventRecord.class, 
                MotionFrameEventRecord.SCHEMA$, 
                new PortableMotionFrameEvent.MessageRecordAdapter(), 
                new PortableMotionFrameEvent.RecordMessageAdapter(), 
                JMSAvroServiceFacade.AVRO_MIME_TYPE, null, 
                new OSGiComponentFactory(context));
        
        RKMessagingConfigUtils.registerAvroSerializationConfig(
                RobotRequest.class, 
                RobotRequestRecord.class, 
                RobotRequestRecord.SCHEMA$, 
                new PortableRobotRequest.MessageRecordAdapter(), 
                new PortableRobotRequest.RecordMessageAdapter(), 
                JMSAvroServiceFacade.AVRO_MIME_TYPE, null, 
                new OSGiComponentFactory(context));
        
        RKMessagingConfigUtils.registerAvroSerializationConfig(
                RobotDefinitionResponse.class, 
                RobotDefinitionResponseRecord.class, 
                RobotDefinitionResponseRecord.SCHEMA$, 
                new PortableRobotDefinitionResponse.MessageRecordAdapter(), 
                new PortableRobotDefinitionResponse.RecordMessageAdapter(), 
                PortableRobotResponse.MIME_ROBOT_DEFINITION_RESPONSE, null, 
                new OSGiComponentFactory(context));
        
        RKMessagingConfigUtils.registerAvroSerializationConfig(
                RobotPositionResponse.class, 
                RobotPositionResponseRecord.class, 
                RobotPositionResponseRecord.SCHEMA$, 
                new PortableRobotPositionResponse.MessageRecordAdapter(), 
                new PortableRobotPositionResponse.RecordMessageAdapter(), 
                PortableRobotResponse.MIME_ROBOT_POSITION_RESPONSE, null, 
                new OSGiComponentFactory(context));
        
        RKMessagingConfigUtils.registerAvroSerializationConfig(
                RobotStatusResponse.class, 
                RobotStatusResponseRecord.class, 
                RobotStatusResponseRecord.SCHEMA$, 
                new PortableRobotStatusResponse.MessageRecordAdapter(), 
                new PortableRobotStatusResponse.RecordMessageAdapter(), 
                PortableRobotResponse.MIME_ROBOT_STATUS_RESPONSE, null, 
                new OSGiComponentFactory(context));
        
        RKMessagingConfigUtils.registerSerializationConfig(
                RobotResponse.class, BytesMessage.class, 
                new PortableRobotResponse.MessageRecordAdapter(), 
                new PortableRobotResponse.RecordMessageAdapter(), 
                null, null, new OSGiComponentFactory(context));
        
        theLogger.log(Level.INFO, "MotionAPI Activation Complete.");
    }

    @Override
    public void stop(BundleContext context) throws Exception {}

}
